import * as cxapi from '@aws-cdk/cx-api';
import { AssetType } from './asset-type';
/**
 * Properties for a `StackDeployment`.
 *
 * @stability stable
 */
export interface StackDeploymentProps {
    /**
     * Artifact ID for this stack.
     *
     * @stability stable
     */
    readonly stackArtifactId: string;
    /**
     * Construct path for this stack.
     *
     * @stability stable
     */
    readonly constructPath: string;
    /**
     * Name for this stack.
     *
     * @stability stable
     */
    readonly stackName: string;
    /**
     * Region where the stack should be deployed.
     *
     * @default - Pipeline region
     * @stability stable
     */
    readonly region?: string;
    /**
     * Account where the stack should be deployed.
     *
     * @default - Pipeline account
     * @stability stable
     */
    readonly account?: string;
    /**
     * Role to assume before deploying this stack.
     *
     * @default - Don't assume any role
     * @stability stable
     */
    readonly assumeRoleArn?: string;
    /**
     * Execution role to pass to CloudFormation.
     *
     * @default - No execution role
     * @stability stable
     */
    readonly executionRoleArn?: string;
    /**
     * Tags to apply to the stack.
     *
     * @default - No tags
     * @stability stable
     */
    readonly tags?: Record<string, string>;
    /**
     * Template path on disk to cloud assembly (cdk.out).
     *
     * @stability stable
     */
    readonly absoluteTemplatePath: string;
    /**
     * Assets referenced by this stack.
     *
     * @default - No assets
     * @stability stable
     */
    readonly assets?: StackAsset[];
    /**
     * The S3 URL which points to the template asset location in the publishing bucket.
     *
     * @default - Stack template is not published
     * @stability stable
     */
    readonly templateS3Uri?: string;
}
/**
 * Deployment of a single Stack.
 *
 * You don't need to instantiate this class -- it will
 * be automatically instantiated as necessary when you
 * add a `Stage` to a pipeline.
 *
 * @stability stable
 */
export declare class StackDeployment {
    /**
     * Build a `StackDeployment` from a Stack Artifact in a Cloud Assembly.
     *
     * @stability stable
     */
    static fromArtifact(stackArtifact: cxapi.CloudFormationStackArtifact): StackDeployment;
    /**
     * Artifact ID for this stack.
     *
     * @stability stable
     */
    readonly stackArtifactId: string;
    /**
     * Construct path for this stack.
     *
     * @stability stable
     */
    readonly constructPath: string;
    /**
     * Name for this stack.
     *
     * @stability stable
     */
    readonly stackName: string;
    /**
     * Region where the stack should be deployed.
     *
     * @default - Pipeline region
     * @stability stable
     */
    readonly region?: string;
    /**
     * Account where the stack should be deployed.
     *
     * @default - Pipeline account
     * @stability stable
     */
    readonly account?: string;
    /**
     * Role to assume before deploying this stack.
     *
     * @default - Don't assume any role
     * @stability stable
     */
    readonly assumeRoleArn?: string;
    /**
     * Execution role to pass to CloudFormation.
     *
     * @default - No execution role
     * @stability stable
     */
    readonly executionRoleArn?: string;
    /**
     * Tags to apply to the stack.
     *
     * @stability stable
     */
    readonly tags: Record<string, string>;
    /**
     * Assets referenced by this stack.
     *
     * @stability stable
     */
    readonly assets: StackAsset[];
    /**
     * Other stacks this stack depends on.
     *
     * @stability stable
     */
    readonly stackDependencies: StackDeployment[];
    /**
     * The asset that represents the CloudFormation template for this stack.
     *
     * @stability stable
     */
    readonly templateAsset?: StackAsset;
    /**
     * The S3 URL which points to the template asset location in the publishing bucket.
     *
     * This is `undefined` if the stack template is not published. Use the
     * `DefaultStackSynthesizer` to ensure it is.
     *
     * @stability stable
     * @example
     *
     * https://bucket.s3.amazonaws.com/object/key
     */
    readonly templateUrl?: string;
    /**
     * Template path on disk to CloudAssembly.
     *
     * @stability stable
     */
    readonly absoluteTemplatePath: string;
    private constructor();
    /**
     * Add a dependency on another stack.
     *
     * @stability stable
     */
    addStackDependency(stackDeployment: StackDeployment): void;
}
/**
 * An asset used by a Stack.
 *
 * @stability stable
 */
export interface StackAsset {
    /**
     * Absolute asset manifest path.
     *
     * This needs to be made relative at a later point in time, but when this
     * information is parsed we don't know about the root cloud assembly yet.
     *
     * @stability stable
     */
    readonly assetManifestPath: string;
    /**
     * Asset identifier.
     *
     * @stability stable
     */
    readonly assetId: string;
    /**
     * Asset selector to pass to `cdk-assets`.
     *
     * @stability stable
     */
    readonly assetSelector: string;
    /**
     * Type of asset to publish.
     *
     * @stability stable
     */
    readonly assetType: AssetType;
    /**
     * Role ARN to assume to publish.
     *
     * @default - No need to assume any role
     * @stability stable
     */
    readonly assetPublishingRoleArn?: string;
    /**
     * Does this asset represent the CloudFormation template for the stack.
     *
     * @default false
     * @stability stable
     */
    readonly isTemplate: boolean;
}
